# Terminology


This is a list of definitions/acronyms that we established for R2X purposes.


## Definitions

{.glossary}
Baseline system
: Representation of the grid infrastructure with components

## Acronymns

{.glossary}
PCM
: Production Cost Model

CEM
: Capacity Expansion Model

ReEDS
: Regional Something. Link

[reVX](https://github.com/NREL/reVX)
: The Renewable Energy Potential(V) eXchange Tool

Plexos
: Energy exemplar production cost model

BESS
: Battery Energy Storage System

WECC
: Western interconect.

## Nodal

{.glossary}
Node
: Bus/Node equivalent

Zone
: Combination of nodes

Prime mover type
: EIA technology category

Fuel type
: EIA fuel type category

Baseline capacity
: Total capacity that exist on the PCM system

Prescribed capacity
: Total capacity identified by CEM system

Investment capacity
: Total capacity to be added to the PCM system based on the prescription capacity

Deactivated capacity
: Amount of capacity to be turn off (unavailable) from the PCM system to meet the CEM system prescription

Uncategorized technology
: Category for generators without a fuel type or technology mapping

LPF
: Load participation factor that captures the contribution of each node in a given zone.

Nodal unit limit
: Total amount of units to allocate in a given node
